﻿using System;
using System.Windows.Forms;
using System.IO;

namespace SierraLauncher
{
    public partial class MainForm : Form
    {
        Launcher launcher;

        public MainForm()
        {
            InitializeComponent();
            launcher = new Launcher();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the About box as a modal form.
            AboutBox about = new AboutBox();
            about.ShowDialog(this);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Close the form
            this.Close();
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Options as a modal form.
            Options options = new Options();
            options.ShowDialog(this);
        }

        private void perGameSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Settings as a modal form.
            PerGameSettings settings = new PerGameSettings();
            settings.ShowDialog(this);
        }

        private void manualToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Open the manual pdf
            launcher.Launch(".\\Manuals\\KQManual.pdf");
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            // Save the user settings before closing the launcher
            // so that they will be the same next time the laucher is used
            SierraLauncher.Properties.Settings.Default.Save();
        }

        #region KQ1
        private void buttonKQ1AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq1\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ1AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ KQ1");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void buttonKQ1SCI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq1sci\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ1SCI)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonKQ1VGA_Click(object sender, EventArgs e)
        {
            try
            {

                // Move to directory
                Directory.SetCurrentDirectory("C:\\Program Files\\Tierra\\KQVGA\\");

                launcher.Launch("kqvga.exe");
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region KQ2
        private void buttonKQ2AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq2\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ2AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ KQ2");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonKQ2VGA_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory("C:\\Program Files\\Tierra\\KQ2VGA\\");

                launcher.Launch("KQ2VGA.exe");
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region KQ3
        private void buttonKQ3AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq3\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ3AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ KQ3");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonKQ3VGA_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory("C:\\Program Files\\IA\\King's Quest III\\");

                launcher.Launch("KQ3.exe");
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region KQ4
        private void buttonKQ4AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq4agi\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ4AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ KQ4");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonKQ4SCI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq4\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ4SCI)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonKQ4VGA_Click(object sender, EventArgs e)
        {

        }
        #endregion

        #region KQ5
        private void buttonKQ5_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq5\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ5)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion

        #region KQ6
        private void buttonKQ6DOS_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq6\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ6DOS)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonKQ6Win_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq6\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ6Win)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRAW.EXE");
                        break;
                    case 1:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRAW.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region KQ7
        private void buttonKQ7_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\kq7\\");

                switch (SierraLauncher.Properties.Settings.Default.KQ7)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE", "-o .\\resource.cfg");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, "-c \"MOUNT C .\" -c C: -c \"SIERRA.EXE -o .\\RESOURCE.CFG\" -c EXIT -conf ..\\dosbox.conf");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "KQ7DOS.BAT");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region KQ8
        private void buttonKQ8_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                DirectoryInfo folder = Directory.GetParent(SierraLauncher.Properties.Settings.Default.KQ8Location);
                Directory.SetCurrentDirectory(folder.ToString());

                // Launch KQ8
                launcher.Launch(SierraLauncher.Properties.Settings.Default.KQ8Location);
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region Other
        private void buttonNick_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Arcades\\");

                switch (SierraLauncher.Properties.Settings.Default.Nick)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE", "-w 0 0 200 320");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, "-c \"MOUNT C .\" -c C: -c \"SCIDHUV.EXE -w 0 0 200 320\" -c EXIT -conf ..\\dosbox.conf");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "NICK.BAT");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonTrivia_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Trivia\\");

                switch (SierraLauncher.Properties.Settings.Default.Trivia)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonChest_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Archive\\");

                switch (SierraLauncher.Properties.Settings.Default.Extra)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonShield_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Archive\\");

                switch (SierraLauncher.Properties.Settings.Default.Extra)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE", "SHIELD.CFG");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, "-c \"MOUNT C .\" -c C: -c \"SIERRA.EXE SHIELD.CFG\" -c EXIT -conf ..\\dosbox.conf");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion
    }
}
