﻿using System;
using System.Windows.Forms;
using System.IO;

namespace SierraLauncher
{
    public partial class MainForm : Form
    {
        Launcher launcher;

        public MainForm()
        {
            InitializeComponent();
            launcher = new Launcher();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the About box as a modal form.
            AboutBox about = new AboutBox();
            about.ShowDialog(this);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Close the form
            this.Close();
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Options as a modal form.
            Options options = new Options();
            options.ShowDialog(this);
        }

        private void perGameSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Settings as a modal form.
            PerGameSettings settings = new PerGameSettings();
            settings.ShowDialog(this);
        }

        private void manualToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Open the manual pdf
            launcher.Launch(".\\Manuals\\LarryManual.pdf");
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            // Save the user settings before closing the launcher
            // so that they will be the same next time the laucher is used
            SierraLauncher.Properties.Settings.Default.Save();
        }

        #region LSL1
        private void buttonLSL1AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl1\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL1AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ LSL1");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void buttonLSL1VGA_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl1vga\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL1VGA)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region LSL2
        private void buttonLSL2_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl2\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL2)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;                    
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;                    
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region LSL3
        private void buttonLSL3_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl3\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL3)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region LSL4
        private void buttonLSL4_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Leisure Suit Larry 4: The Missing Floppies cannot be found", "Cannot Find Game", MessageBoxButtons.OK, MessageBoxIcon.Warning);
        }
        #endregion

        #region LSL5
        private void buttonLSL5_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl5\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL5)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        #endregion

        #region LSL6
        private void buttonLSL6_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl6\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL6)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region LSL7
        private void buttonLSL7_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\lsl7\\");

                switch (SierraLauncher.Properties.Settings.Default.LSL7)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIER.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIER.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIER.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region Other
        private void buttonNick_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Arcades\\");

                switch (SierraLauncher.Properties.Settings.Default.Nick)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonLaffer_Click(object sender, EventArgs e)
        {
            // Display the Laffer Utilities Launchpad as a modal form.
            LafferUtilities utilities = new LafferUtilities();
            utilities.ShowDialog(this);
        }
        #endregion

    }
}
