﻿using System;
using System.Windows.Forms;
using System.IO;

namespace SierraLauncher
{
    public partial class MainForm : Form
    {
        Launcher launcher;

        public MainForm()
        {
            InitializeComponent();
            launcher = new Launcher();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the About box as a modal form.
            AboutBox about = new AboutBox();
            about.ShowDialog(this);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Close the form
            this.Close();
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Options as a modal form.
            Options options = new Options();
            options.ShowDialog(this);
        }

        private void perGameSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Settings as a modal form.
            PerGameSettings settings = new PerGameSettings();
            settings.ShowDialog(this);
        }

        private void manualToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Open the manual pdf
            launcher.Launch(".\\Manuals\\PQManual.pdf");
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            // Save the user settings before closing the launcher
            // so that they will be the same next time the laucher is used
            SierraLauncher.Properties.Settings.Default.Save();
        }        

        #region PQ1
        private void buttonPQ1AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\pq1\\");

                switch (SierraLauncher.Properties.Settings.Default.PQ1AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("PQ.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\PQ.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "PQ.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ PQ1");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonPQ1VGA_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\pq1_vga\\");

                switch (SierraLauncher.Properties.Settings.Default.PQ1VGA)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region PQ2
        private void buttonPQ2_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\pq2\\");

                switch (SierraLauncher.Properties.Settings.Default.PQ2)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region PQ3
        private void buttonPQ3_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\pq3\\");

                switch (SierraLauncher.Properties.Settings.Default.PQ3)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region PQ4
        private void buttonPQ4_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\pq4\\");

                switch (SierraLauncher.Properties.Settings.Default.PQ4)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE", ".//RESOURCE.CFG");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, "-c \"MOUNT C .\" -c C: -c \"SIERRA.EXE .\\RESOURCE.CFG\" -c EXIT -conf ..\\dosbox.conf");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

    }
}
