﻿using System;
using System.Windows.Forms;
using System.IO;

namespace SierraLauncher
{
    public partial class MainForm : Form
    {
        Launcher launcher;

        public MainForm()
        {
            InitializeComponent();
            launcher = new Launcher();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the About box as a modal form.
            AboutBox about = new AboutBox();
            about.ShowDialog(this);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Close the form
            this.Close();
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Options as a modal form.
            Options options = new Options();
            options.ShowDialog(this);
        }

        private void perGameSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Settings as a modal form.
            PerGameSettings settings = new PerGameSettings();
            settings.ShowDialog(this);
        }

        private void manualToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Open the manual pdf
            launcher.Launch(".\\Manuals\\QfGManual.pdf");
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            // Save the user settings before closing the launcher
            // so that they will be the same next time the laucher is used
            SierraLauncher.Properties.Settings.Default.Save();
        }

        #region QfG1
        private void buttonQfG1SCI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\qg1\\");

                switch (SierraLauncher.Properties.Settings.Default.QfG1SCI)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonQfG1VGA_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\qg1vga\\");

                switch (SierraLauncher.Properties.Settings.Default.QfG1VGA)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region QfG2
        private void buttonQfG2SCI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\qg2\\");

                switch (SierraLauncher.Properties.Settings.Default.QfG2SCI)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonQfG2VGA_Click(object sender, EventArgs e)
        {
            try
            {

                // Move to directory
                Directory.SetCurrentDirectory("C:\\Program Files\\AGD Interactive\\Quest for Glory II\\");

                launcher.Launch("Qfg2vga.exe");
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region QfG3
        private void buttonQfG3_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\qg3\\");

                switch (SierraLauncher.Properties.Settings.Default.QfG3)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region QfG4
        private void buttonQfG4_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\qg4\\");

                switch (SierraLauncher.Properties.Settings.Default.QfG4)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region QfG5
        private void buttonQfG5_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                DirectoryInfo folder = Directory.GetParent(SierraLauncher.Properties.Settings.Default.QfG5Location);
                Directory.SetCurrentDirectory(folder.ToString());

                // Launch QfG5
                launcher.Launch(SierraLauncher.Properties.Settings.Default.QfG5Location);
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }            
        }
        #endregion
    }
}
