﻿using System;
using System.Windows.Forms;
using System.IO;

namespace SierraLauncher
{
    public partial class MainForm : Form
    {
        Launcher launcher;

        public MainForm()
        {
            InitializeComponent();
            launcher = new Launcher();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the About box as a modal form.
            AboutBox about = new AboutBox();
            about.ShowDialog(this);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Close the form
            this.Close();
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Options as a modal form.
            Options options = new Options();
            options.ShowDialog(this);
        }

        private void perGameSettingsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Display the Settings as a modal form.
            PerGameSettings settings = new PerGameSettings();
            settings.ShowDialog(this);
        }

        private void manualToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Open the manual pdf
            launcher.Launch(".\\Manuals\\SQManual.pdf");
        }

        private void viewSQ6ManualToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Open the manual pdf
            launcher.Launch(".\\Manuals\\SQ6Manual.pdf");
        }

        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            // Save the user settings before closing the launcher
            // so that they will be the same next time the laucher is used
            SierraLauncher.Properties.Settings.Default.Save();
        }        

        #region SQ1
        private void buttonSQ1AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq1\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ1AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ SQ1");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonSQ1VGA_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq1vga\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ1VGA)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region SQ2
        private void buttonSQ2AGI_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq2\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ2AGI)
                {
                    case 0:
                        // Use the normal Interpreter
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use the NAGI Interpreter
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.NAGILocation);
                        break;
                    case 2:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 3:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    case 4:
                        // Use SCUMMVM
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.SCUMMVMLocation, "-p .\\ SQ2");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region SQ3
        private void buttonSQ3_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq3\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ3)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region SQ4
        private void buttonSQ4_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq4\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ4)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region SQ5
        private void buttonSQ5_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq5\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ5)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region SQ6
        private void buttonSQ6Demo_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq6demo\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ6Demo)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        
        private void buttonSQ6_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\sq6\\");

                switch (SierraLauncher.Properties.Settings.Default.SQ6)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.EXE", "-o .\\RESOURCE.CFG");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, "-c \"MOUNT C .\" -c C: -c \"SIERRA.EXE -o .\\RESOURCE.CFG\" -c EXIT -conf ..\\dosbox.conf");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SQ6.BAT");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion

        #region Other
        private void buttonNick_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Arcades\\");

                switch (SierraLauncher.Properties.Settings.Default.Nick)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SCIDHUV.EXE");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SCIDHUV.EXE -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SCIDHUV.EXE");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonAstro_Click(object sender, EventArgs e)
        {
            try
            {
                // Move to directory
                Directory.SetCurrentDirectory(".\\Astro\\");

                switch (SierraLauncher.Properties.Settings.Default.Astro)
                {
                    case 0:
                        // Use Nothing
                        launcher.Launch("SIERRA.COM");
                        break;
                    case 1:
                        // Use DOSBox
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.DOSBoxLocation, ".\\SIERRA.COM -conf ..\\dosbox.conf -exit");
                        break;
                    case 2:
                        // Use VDMSound
                        launcher.Launch(SierraLauncher.Properties.Settings.Default.VDMSoundLocation, "SIERRA.COM");
                        break;
                    default:
                        break;
                }
            }
            catch (DirectoryNotFoundException ex)
            {
                MessageBox.Show(ex.Message, "Cannot Find Directory", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        #endregion
    }
}
